# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: donations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='donations.proto',
  package='org.couchers.api.donations',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x64onations.proto\x12\x1aorg.couchers.api.donations\x1a\x11\x61nnotations.proto\"8\n\x13InitiateDonationReq\x12\x0e\n\x06\x61mount\x18\x01 \x01(\r\x12\x11\n\trecurring\x18\x02 \x01(\x08\"9\n\x13InitiateDonationRes\x12\"\n\x1astripe_checkout_session_id\x18\x01 \x01(\t2\x89\x01\n\tDonations\x12v\n\x10InitiateDonation\x12/.org.couchers.api.donations.InitiateDonationReq\x1a/.org.couchers.api.donations.InitiateDonationRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,])




_INITIATEDONATIONREQ = _descriptor.Descriptor(
  name='InitiateDonationReq',
  full_name='org.couchers.api.donations.InitiateDonationReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.couchers.api.donations.InitiateDonationReq.amount', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurring', full_name='org.couchers.api.donations.InitiateDonationReq.recurring', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=122,
)


_INITIATEDONATIONRES = _descriptor.Descriptor(
  name='InitiateDonationRes',
  full_name='org.couchers.api.donations.InitiateDonationRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stripe_checkout_session_id', full_name='org.couchers.api.donations.InitiateDonationRes.stripe_checkout_session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=181,
)

DESCRIPTOR.message_types_by_name['InitiateDonationReq'] = _INITIATEDONATIONREQ
DESCRIPTOR.message_types_by_name['InitiateDonationRes'] = _INITIATEDONATIONRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitiateDonationReq = _reflection.GeneratedProtocolMessageType('InitiateDonationReq', (_message.Message,), {
  'DESCRIPTOR' : _INITIATEDONATIONREQ,
  '__module__' : 'donations_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.donations.InitiateDonationReq)
  })
_sym_db.RegisterMessage(InitiateDonationReq)

InitiateDonationRes = _reflection.GeneratedProtocolMessageType('InitiateDonationRes', (_message.Message,), {
  'DESCRIPTOR' : _INITIATEDONATIONRES,
  '__module__' : 'donations_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.donations.InitiateDonationRes)
  })
_sym_db.RegisterMessage(InitiateDonationRes)



_DONATIONS = _descriptor.ServiceDescriptor(
  name='Donations',
  full_name='org.couchers.api.donations.Donations',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=184,
  serialized_end=321,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitiateDonation',
    full_name='org.couchers.api.donations.Donations.InitiateDonation',
    index=0,
    containing_service=None,
    input_type=_INITIATEDONATIONREQ,
    output_type=_INITIATEDONATIONRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DONATIONS)

DESCRIPTOR.services_by_name['Donations'] = _DONATIONS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stripe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stripe.proto',
  package='org.couchers.stripe',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cstripe.proto\x12\x13org.couchers.stripe\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x11\x61nnotations.proto2^\n\x06Stripe\x12N\n\x07Webhook\x12\x14.google.api.HttpBody\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/stripe/webhook\x1a\x04\x88\xb5\x18\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_httpbody__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_STRIPE = _descriptor.ServiceDescriptor(
  name='Stripe',
  full_name='org.couchers.stripe.Stripe',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=113,
  serialized_end=207,
  methods=[
  _descriptor.MethodDescriptor(
    name='Webhook',
    full_name='org.couchers.stripe.Stripe.Webhook',
    index=0,
    containing_service=None,
    input_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\021\"\017/stripe/webhook',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STRIPE)

DESCRIPTOR.services_by_name['Stripe'] = _STRIPE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import bugs_pb2 as bugs__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BugsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Version = channel.unary_unary(
                '/org.couchers.bugs.Bugs/Version',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bugs__pb2.VersionInfo.FromString,
                )
        self.ReportBug = channel.unary_unary(
                '/org.couchers.bugs.Bugs/ReportBug',
                request_serializer=bugs__pb2.ReportBugReq.SerializeToString,
                response_deserializer=bugs__pb2.ReportBugRes.FromString,
                )


class BugsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportBug(self, request, context):
        """Report a bug
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BugsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Version': grpc.unary_unary_rpc_method_handler(
                    servicer.Version,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bugs__pb2.VersionInfo.SerializeToString,
            ),
            'ReportBug': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportBug,
                    request_deserializer=bugs__pb2.ReportBugReq.FromString,
                    response_serializer=bugs__pb2.ReportBugRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.bugs.Bugs', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Bugs(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/Version',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bugs__pb2.VersionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportBug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/ReportBug',
            bugs__pb2.ReportBugReq.SerializeToString,
            bugs__pb2.ReportBugRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import threads_pb2 as threads__pb2


class ThreadsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetThread = channel.unary_unary(
                '/org.couchers.api.threads.Threads/GetThread',
                request_serializer=threads__pb2.GetThreadReq.SerializeToString,
                response_deserializer=threads__pb2.GetThreadRes.FromString,
                )
        self.PostReply = channel.unary_unary(
                '/org.couchers.api.threads.Threads/PostReply',
                request_serializer=threads__pb2.PostReplyReq.SerializeToString,
                response_deserializer=threads__pb2.PostReplyRes.FromString,
                )


class ThreadsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetThread(self, request, context):
        """Discussion threads are organized as a tree with maximum three levels depth:
        thread1
        +- comment1
        |  +- reply1
        |  +- reply2
        +- comment2
        +- reply3
        +- reply4
        thread2
        +- comment3
        |  +- reply5
        |  +- reply6
        +- comment4
        +- reply7
        +- reply8

        The same API is used regardless of level. All posts are using the same id namespace.

        Get non-deleted posts belonging to a thread, sorted in reverse time order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostReply(self, request, context):
        """Post a new comment on a thread. The post can not be changed or deleted after posting.
        Throws NOT_FOUND if thread_id corresponds to a nesting level 3 reply, since no futher nesting is allowed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ThreadsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetThread': grpc.unary_unary_rpc_method_handler(
                    servicer.GetThread,
                    request_deserializer=threads__pb2.GetThreadReq.FromString,
                    response_serializer=threads__pb2.GetThreadRes.SerializeToString,
            ),
            'PostReply': grpc.unary_unary_rpc_method_handler(
                    servicer.PostReply,
                    request_deserializer=threads__pb2.PostReplyReq.FromString,
                    response_serializer=threads__pb2.PostReplyRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.threads.Threads', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Threads(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetThread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.threads.Threads/GetThread',
            threads__pb2.GetThreadReq.SerializeToString,
            threads__pb2.GetThreadRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostReply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.threads.Threads/PostReply',
            threads__pb2.PostReplyReq.SerializeToString,
            threads__pb2.PostReplyRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='resources.proto',
  package='org.couchers.resources',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fresources.proto\x12\x16org.couchers.resources\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"0\n\x14GetTermsOfServiceRes\x12\x18\n\x10terms_of_service\x18\x01 \x01(\t\"H\n\x12\x43ommunityGuideline\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tguideline\x18\x02 \x01(\t\x12\x10\n\x08icon_svg\x18\x03 \x01(\t\"e\n\x19GetCommunityGuidelinesRes\x12H\n\x14\x63ommunity_guidelines\x18\x01 \x03(\x0b\x32*.org.couchers.resources.CommunityGuideline\"&\n\x06Region\x12\x0e\n\x06\x61lpha3\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"@\n\rGetRegionsRes\x12/\n\x07regions\x18\x01 \x03(\x0b\x32\x1e.org.couchers.resources.Region\"&\n\x08Language\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"F\n\x0fGetLanguagesRes\x12\x33\n\tlanguages\x18\x01 \x03(\x0b\x32 .org.couchers.resources.Language2\xf7\x02\n\tResources\x12[\n\x11GetTermsOfService\x12\x16.google.protobuf.Empty\x1a,.org.couchers.resources.GetTermsOfServiceRes\"\x00\x12\x65\n\x16GetCommunityGuidelines\x12\x16.google.protobuf.Empty\x1a\x31.org.couchers.resources.GetCommunityGuidelinesRes\"\x00\x12M\n\nGetRegions\x12\x16.google.protobuf.Empty\x1a%.org.couchers.resources.GetRegionsRes\"\x00\x12Q\n\x0cGetLanguages\x12\x16.google.protobuf.Empty\x1a\'.org.couchers.resources.GetLanguagesRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_GETTERMSOFSERVICERES = _descriptor.Descriptor(
  name='GetTermsOfServiceRes',
  full_name='org.couchers.resources.GetTermsOfServiceRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='terms_of_service', full_name='org.couchers.resources.GetTermsOfServiceRes.terms_of_service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=139,
)


_COMMUNITYGUIDELINE = _descriptor.Descriptor(
  name='CommunityGuideline',
  full_name='org.couchers.resources.CommunityGuideline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.resources.CommunityGuideline.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guideline', full_name='org.couchers.resources.CommunityGuideline.guideline', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon_svg', full_name='org.couchers.resources.CommunityGuideline.icon_svg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=213,
)


_GETCOMMUNITYGUIDELINESRES = _descriptor.Descriptor(
  name='GetCommunityGuidelinesRes',
  full_name='org.couchers.resources.GetCommunityGuidelinesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_guidelines', full_name='org.couchers.resources.GetCommunityGuidelinesRes.community_guidelines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=316,
)


_REGION = _descriptor.Descriptor(
  name='Region',
  full_name='org.couchers.resources.Region',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alpha3', full_name='org.couchers.resources.Region.alpha3', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.resources.Region.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=356,
)


_GETREGIONSRES = _descriptor.Descriptor(
  name='GetRegionsRes',
  full_name='org.couchers.resources.GetRegionsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='regions', full_name='org.couchers.resources.GetRegionsRes.regions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=422,
)


_LANGUAGE = _descriptor.Descriptor(
  name='Language',
  full_name='org.couchers.resources.Language',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='org.couchers.resources.Language.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.resources.Language.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=462,
)


_GETLANGUAGESRES = _descriptor.Descriptor(
  name='GetLanguagesRes',
  full_name='org.couchers.resources.GetLanguagesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='languages', full_name='org.couchers.resources.GetLanguagesRes.languages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=534,
)

_GETCOMMUNITYGUIDELINESRES.fields_by_name['community_guidelines'].message_type = _COMMUNITYGUIDELINE
_GETREGIONSRES.fields_by_name['regions'].message_type = _REGION
_GETLANGUAGESRES.fields_by_name['languages'].message_type = _LANGUAGE
DESCRIPTOR.message_types_by_name['GetTermsOfServiceRes'] = _GETTERMSOFSERVICERES
DESCRIPTOR.message_types_by_name['CommunityGuideline'] = _COMMUNITYGUIDELINE
DESCRIPTOR.message_types_by_name['GetCommunityGuidelinesRes'] = _GETCOMMUNITYGUIDELINESRES
DESCRIPTOR.message_types_by_name['Region'] = _REGION
DESCRIPTOR.message_types_by_name['GetRegionsRes'] = _GETREGIONSRES
DESCRIPTOR.message_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.message_types_by_name['GetLanguagesRes'] = _GETLANGUAGESRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTermsOfServiceRes = _reflection.GeneratedProtocolMessageType('GetTermsOfServiceRes', (_message.Message,), {
  'DESCRIPTOR' : _GETTERMSOFSERVICERES,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.GetTermsOfServiceRes)
  })
_sym_db.RegisterMessage(GetTermsOfServiceRes)

CommunityGuideline = _reflection.GeneratedProtocolMessageType('CommunityGuideline', (_message.Message,), {
  'DESCRIPTOR' : _COMMUNITYGUIDELINE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.CommunityGuideline)
  })
_sym_db.RegisterMessage(CommunityGuideline)

GetCommunityGuidelinesRes = _reflection.GeneratedProtocolMessageType('GetCommunityGuidelinesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMUNITYGUIDELINESRES,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.GetCommunityGuidelinesRes)
  })
_sym_db.RegisterMessage(GetCommunityGuidelinesRes)

Region = _reflection.GeneratedProtocolMessageType('Region', (_message.Message,), {
  'DESCRIPTOR' : _REGION,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.Region)
  })
_sym_db.RegisterMessage(Region)

GetRegionsRes = _reflection.GeneratedProtocolMessageType('GetRegionsRes', (_message.Message,), {
  'DESCRIPTOR' : _GETREGIONSRES,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.GetRegionsRes)
  })
_sym_db.RegisterMessage(GetRegionsRes)

Language = _reflection.GeneratedProtocolMessageType('Language', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.Language)
  })
_sym_db.RegisterMessage(Language)

GetLanguagesRes = _reflection.GeneratedProtocolMessageType('GetLanguagesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETLANGUAGESRES,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.resources.GetLanguagesRes)
  })
_sym_db.RegisterMessage(GetLanguagesRes)



_RESOURCES = _descriptor.ServiceDescriptor(
  name='Resources',
  full_name='org.couchers.resources.Resources',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=537,
  serialized_end=912,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetTermsOfService',
    full_name='org.couchers.resources.Resources.GetTermsOfService',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETTERMSOFSERVICERES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommunityGuidelines',
    full_name='org.couchers.resources.Resources.GetCommunityGuidelines',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETCOMMUNITYGUIDELINESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRegions',
    full_name='org.couchers.resources.Resources.GetRegions',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETREGIONSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLanguages',
    full_name='org.couchers.resources.Resources.GetLanguages',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETLANGUAGESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RESOURCES)

DESCRIPTOR.services_by_name['Resources'] = _RESOURCES

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: references.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='references.proto',
  package='org.couchers.api.references',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10references.proto\x12\x1borg.couchers.api.references\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\xe8\x01\n\tReference\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x66rom_user_id\x18\x02 \x01(\x03\x12\x12\n\nto_user_id\x18\x03 \x01(\x03\x12\x42\n\x0ereference_type\x18\x04 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x30\n\x0cwritten_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fhost_request_id\x18\x07 \x01(\x03\"\xaf\x01\n\x11ListReferencesReq\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\x12I\n\x15reference_type_filter\x18\x03 \x03(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x11\n\tpage_size\x18\x04 \x01(\r\x12\x12\n\npage_token\x18\x05 \x01(\t\"h\n\x11ListReferencesRes\x12:\n\nreferences\x18\x01 \x03(\x0b\x32&.org.couchers.api.references.Reference\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"d\n\x17WriteFriendReferenceReq\x12\x12\n\nto_user_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x17\n\x0fwas_appropriate\x18\x03 \x01(\x08\x12\x0e\n\x06rating\x18\x04 \x01(\x01\"n\n\x1cWriteHostRequestReferenceReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x17\n\x0fwas_appropriate\x18\x03 \x01(\x08\x12\x0e\n\x06rating\x18\x04 \x01(\x01\"1\n\x1b\x41vailableWriteReferencesReq\x12\x12\n\nto_user_id\x18\x01 \x01(\x03\"\xac\x01\n\x1b\x41vailableWriteReferenceType\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x42\n\x0ereference_type\x18\x02 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x30\n\x0ctime_expires\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9f\x01\n\x1b\x41vailableWriteReferencesRes\x12\"\n\x1a\x63\x61n_write_friend_reference\x18\x01 \x01(\x08\x12\\\n\x1a\x61vailable_write_references\x18\x02 \x03(\x0b\x32\x38.org.couchers.api.references.AvailableWriteReferenceType\"w\n\x1fListPendingReferencesToWriteRes\x12T\n\x12pending_references\x18\x01 \x03(\x0b\x32\x38.org.couchers.api.references.AvailableWriteReferenceType*`\n\rReferenceType\x12\x19\n\x15REFERENCE_TYPE_FRIEND\x10\x00\x12\x19\n\x15REFERENCE_TYPE_SURFED\x10\x01\x12\x19\n\x15REFERENCE_TYPE_HOSTED\x10\x02\x32\x8c\x05\n\nReferences\x12r\n\x0eListReferences\x12..org.couchers.api.references.ListReferencesReq\x1a..org.couchers.api.references.ListReferencesRes\"\x00\x12v\n\x14WriteFriendReference\x12\x34.org.couchers.api.references.WriteFriendReferenceReq\x1a&.org.couchers.api.references.Reference\"\x00\x12\x80\x01\n\x19WriteHostRequestReference\x12\x39.org.couchers.api.references.WriteHostRequestReferenceReq\x1a&.org.couchers.api.references.Reference\"\x00\x12\x90\x01\n\x18\x41vailableWriteReferences\x12\x38.org.couchers.api.references.AvailableWriteReferencesReq\x1a\x38.org.couchers.api.references.AvailableWriteReferencesRes\"\x00\x12v\n\x1cListPendingReferencesToWrite\x12\x16.google.protobuf.Empty\x1a<.org.couchers.api.references.ListPendingReferencesToWriteRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])

_REFERENCETYPE = _descriptor.EnumDescriptor(
  name='ReferenceType',
  full_name='org.couchers.api.references.ReferenceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_TYPE_FRIEND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_TYPE_SURFED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_TYPE_HOSTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1372,
  serialized_end=1468,
)
_sym_db.RegisterEnumDescriptor(_REFERENCETYPE)

ReferenceType = enum_type_wrapper.EnumTypeWrapper(_REFERENCETYPE)
REFERENCE_TYPE_FRIEND = 0
REFERENCE_TYPE_SURFED = 1
REFERENCE_TYPE_HOSTED = 2



_REFERENCE = _descriptor.Descriptor(
  name='Reference',
  full_name='org.couchers.api.references.Reference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_id', full_name='org.couchers.api.references.Reference.reference_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='org.couchers.api.references.Reference.from_user_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='org.couchers.api.references.Reference.to_user_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_type', full_name='org.couchers.api.references.Reference.reference_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.references.Reference.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='written_time', full_name='org.couchers.api.references.Reference.written_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.references.Reference.host_request_id', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=363,
)


_LISTREFERENCESREQ = _descriptor.Descriptor(
  name='ListReferencesReq',
  full_name='org.couchers.api.references.ListReferencesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='org.couchers.api.references.ListReferencesReq.from_user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='org.couchers.api.references.ListReferencesReq.to_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_type_filter', full_name='org.couchers.api.references.ListReferencesReq.reference_type_filter', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.references.ListReferencesReq.page_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.references.ListReferencesReq.page_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=541,
)


_LISTREFERENCESRES = _descriptor.Descriptor(
  name='ListReferencesRes',
  full_name='org.couchers.api.references.ListReferencesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='references', full_name='org.couchers.api.references.ListReferencesRes.references', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.references.ListReferencesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=647,
)


_WRITEFRIENDREFERENCEREQ = _descriptor.Descriptor(
  name='WriteFriendReferenceReq',
  full_name='org.couchers.api.references.WriteFriendReferenceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='org.couchers.api.references.WriteFriendReferenceReq.to_user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.references.WriteFriendReferenceReq.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='was_appropriate', full_name='org.couchers.api.references.WriteFriendReferenceReq.was_appropriate', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rating', full_name='org.couchers.api.references.WriteFriendReferenceReq.rating', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=749,
)


_WRITEHOSTREQUESTREFERENCEREQ = _descriptor.Descriptor(
  name='WriteHostRequestReferenceReq',
  full_name='org.couchers.api.references.WriteHostRequestReferenceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.references.WriteHostRequestReferenceReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.references.WriteHostRequestReferenceReq.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='was_appropriate', full_name='org.couchers.api.references.WriteHostRequestReferenceReq.was_appropriate', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rating', full_name='org.couchers.api.references.WriteHostRequestReferenceReq.rating', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=861,
)


_AVAILABLEWRITEREFERENCESREQ = _descriptor.Descriptor(
  name='AvailableWriteReferencesReq',
  full_name='org.couchers.api.references.AvailableWriteReferencesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='org.couchers.api.references.AvailableWriteReferencesReq.to_user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=912,
)


_AVAILABLEWRITEREFERENCETYPE = _descriptor.Descriptor(
  name='AvailableWriteReferenceType',
  full_name='org.couchers.api.references.AvailableWriteReferenceType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.references.AvailableWriteReferenceType.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_type', full_name='org.couchers.api.references.AvailableWriteReferenceType.reference_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_expires', full_name='org.couchers.api.references.AvailableWriteReferenceType.time_expires', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=915,
  serialized_end=1087,
)


_AVAILABLEWRITEREFERENCESRES = _descriptor.Descriptor(
  name='AvailableWriteReferencesRes',
  full_name='org.couchers.api.references.AvailableWriteReferencesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_write_friend_reference', full_name='org.couchers.api.references.AvailableWriteReferencesRes.can_write_friend_reference', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_write_references', full_name='org.couchers.api.references.AvailableWriteReferencesRes.available_write_references', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1249,
)


_LISTPENDINGREFERENCESTOWRITERES = _descriptor.Descriptor(
  name='ListPendingReferencesToWriteRes',
  full_name='org.couchers.api.references.ListPendingReferencesToWriteRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pending_references', full_name='org.couchers.api.references.ListPendingReferencesToWriteRes.pending_references', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1370,
)

_REFERENCE.fields_by_name['reference_type'].enum_type = _REFERENCETYPE
_REFERENCE.fields_by_name['written_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTREFERENCESREQ.fields_by_name['reference_type_filter'].enum_type = _REFERENCETYPE
_LISTREFERENCESRES.fields_by_name['references'].message_type = _REFERENCE
_AVAILABLEWRITEREFERENCETYPE.fields_by_name['reference_type'].enum_type = _REFERENCETYPE
_AVAILABLEWRITEREFERENCETYPE.fields_by_name['time_expires'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AVAILABLEWRITEREFERENCESRES.fields_by_name['available_write_references'].message_type = _AVAILABLEWRITEREFERENCETYPE
_LISTPENDINGREFERENCESTOWRITERES.fields_by_name['pending_references'].message_type = _AVAILABLEWRITEREFERENCETYPE
DESCRIPTOR.message_types_by_name['Reference'] = _REFERENCE
DESCRIPTOR.message_types_by_name['ListReferencesReq'] = _LISTREFERENCESREQ
DESCRIPTOR.message_types_by_name['ListReferencesRes'] = _LISTREFERENCESRES
DESCRIPTOR.message_types_by_name['WriteFriendReferenceReq'] = _WRITEFRIENDREFERENCEREQ
DESCRIPTOR.message_types_by_name['WriteHostRequestReferenceReq'] = _WRITEHOSTREQUESTREFERENCEREQ
DESCRIPTOR.message_types_by_name['AvailableWriteReferencesReq'] = _AVAILABLEWRITEREFERENCESREQ
DESCRIPTOR.message_types_by_name['AvailableWriteReferenceType'] = _AVAILABLEWRITEREFERENCETYPE
DESCRIPTOR.message_types_by_name['AvailableWriteReferencesRes'] = _AVAILABLEWRITEREFERENCESRES
DESCRIPTOR.message_types_by_name['ListPendingReferencesToWriteRes'] = _LISTPENDINGREFERENCESTOWRITERES
DESCRIPTOR.enum_types_by_name['ReferenceType'] = _REFERENCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reference = _reflection.GeneratedProtocolMessageType('Reference', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.Reference)
  })
_sym_db.RegisterMessage(Reference)

ListReferencesReq = _reflection.GeneratedProtocolMessageType('ListReferencesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTREFERENCESREQ,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.ListReferencesReq)
  })
_sym_db.RegisterMessage(ListReferencesReq)

ListReferencesRes = _reflection.GeneratedProtocolMessageType('ListReferencesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTREFERENCESRES,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.ListReferencesRes)
  })
_sym_db.RegisterMessage(ListReferencesRes)

WriteFriendReferenceReq = _reflection.GeneratedProtocolMessageType('WriteFriendReferenceReq', (_message.Message,), {
  'DESCRIPTOR' : _WRITEFRIENDREFERENCEREQ,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.WriteFriendReferenceReq)
  })
_sym_db.RegisterMessage(WriteFriendReferenceReq)

WriteHostRequestReferenceReq = _reflection.GeneratedProtocolMessageType('WriteHostRequestReferenceReq', (_message.Message,), {
  'DESCRIPTOR' : _WRITEHOSTREQUESTREFERENCEREQ,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.WriteHostRequestReferenceReq)
  })
_sym_db.RegisterMessage(WriteHostRequestReferenceReq)

AvailableWriteReferencesReq = _reflection.GeneratedProtocolMessageType('AvailableWriteReferencesReq', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEWRITEREFERENCESREQ,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.AvailableWriteReferencesReq)
  })
_sym_db.RegisterMessage(AvailableWriteReferencesReq)

AvailableWriteReferenceType = _reflection.GeneratedProtocolMessageType('AvailableWriteReferenceType', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEWRITEREFERENCETYPE,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.AvailableWriteReferenceType)
  })
_sym_db.RegisterMessage(AvailableWriteReferenceType)

AvailableWriteReferencesRes = _reflection.GeneratedProtocolMessageType('AvailableWriteReferencesRes', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEWRITEREFERENCESRES,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.AvailableWriteReferencesRes)
  })
_sym_db.RegisterMessage(AvailableWriteReferencesRes)

ListPendingReferencesToWriteRes = _reflection.GeneratedProtocolMessageType('ListPendingReferencesToWriteRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTPENDINGREFERENCESTOWRITERES,
  '__module__' : 'references_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.references.ListPendingReferencesToWriteRes)
  })
_sym_db.RegisterMessage(ListPendingReferencesToWriteRes)



_REFERENCES = _descriptor.ServiceDescriptor(
  name='References',
  full_name='org.couchers.api.references.References',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=1471,
  serialized_end=2123,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListReferences',
    full_name='org.couchers.api.references.References.ListReferences',
    index=0,
    containing_service=None,
    input_type=_LISTREFERENCESREQ,
    output_type=_LISTREFERENCESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteFriendReference',
    full_name='org.couchers.api.references.References.WriteFriendReference',
    index=1,
    containing_service=None,
    input_type=_WRITEFRIENDREFERENCEREQ,
    output_type=_REFERENCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteHostRequestReference',
    full_name='org.couchers.api.references.References.WriteHostRequestReference',
    index=2,
    containing_service=None,
    input_type=_WRITEHOSTREQUESTREFERENCEREQ,
    output_type=_REFERENCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AvailableWriteReferences',
    full_name='org.couchers.api.references.References.AvailableWriteReferences',
    index=3,
    containing_service=None,
    input_type=_AVAILABLEWRITEREFERENCESREQ,
    output_type=_AVAILABLEWRITEREFERENCESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPendingReferencesToWrite',
    full_name='org.couchers.api.references.References.ListPendingReferencesToWrite',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTPENDINGREFERENCESTOWRITERES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REFERENCES)

DESCRIPTOR.services_by_name['References'] = _REFERENCES

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discussions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='discussions.proto',
  package='org.couchers.api.discussions',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x64iscussions.proto\x12\x1corg.couchers.api.discussions\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"\xa0\x02\n\nDiscussion\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x63reator_user_id\x18\x04 \x01(\x03\x12\x1c\n\x12owner_community_id\x18\x05 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\x06 \x01(\x03H\x00\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t\x12\x30\n\x06thread\x18\x0b \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\x14\n\x0c\x63\x61n_moderate\x18\n \x01(\x08\x42\x07\n\x05owner\"v\n\x13\x43reateDiscussionReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x1c\n\x12owner_community_id\x18\x03 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\x04 \x01(\x03H\x00\x42\x07\n\x05owner\")\n\x10GetDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x32\xf3\x01\n\x0b\x44iscussions\x12q\n\x10\x43reateDiscussion\x12\x31.org.couchers.api.discussions.CreateDiscussionReq\x1a(.org.couchers.api.discussions.Discussion\"\x00\x12k\n\rGetDiscussion\x12..org.couchers.api.discussions.GetDiscussionReq\x1a(.org.couchers.api.discussions.Discussion\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,threads__pb2.DESCRIPTOR,])




_DISCUSSION = _descriptor.Descriptor(
  name='Discussion',
  full_name='org.couchers.api.discussions.Discussion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discussion_id', full_name='org.couchers.api.discussions.Discussion.discussion_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.discussions.Discussion.slug', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.discussions.Discussion.created', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_user_id', full_name='org.couchers.api.discussions.Discussion.creator_user_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_community_id', full_name='org.couchers.api.discussions.Discussion.owner_community_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_group_id', full_name='org.couchers.api.discussions.Discussion.owner_group_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.discussions.Discussion.title', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.discussions.Discussion.content', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thread', full_name='org.couchers.api.discussions.Discussion.thread', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_moderate', full_name='org.couchers.api.discussions.Discussion.can_moderate', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='owner', full_name='org.couchers.api.discussions.Discussion.owner',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=119,
  serialized_end=407,
)


_CREATEDISCUSSIONREQ = _descriptor.Descriptor(
  name='CreateDiscussionReq',
  full_name='org.couchers.api.discussions.CreateDiscussionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.discussions.CreateDiscussionReq.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.discussions.CreateDiscussionReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_community_id', full_name='org.couchers.api.discussions.CreateDiscussionReq.owner_community_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_group_id', full_name='org.couchers.api.discussions.CreateDiscussionReq.owner_group_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='owner', full_name='org.couchers.api.discussions.CreateDiscussionReq.owner',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=409,
  serialized_end=527,
)


_GETDISCUSSIONREQ = _descriptor.Descriptor(
  name='GetDiscussionReq',
  full_name='org.couchers.api.discussions.GetDiscussionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discussion_id', full_name='org.couchers.api.discussions.GetDiscussionReq.discussion_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=570,
)

_DISCUSSION.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DISCUSSION.fields_by_name['thread'].message_type = threads__pb2._THREAD
_DISCUSSION.oneofs_by_name['owner'].fields.append(
  _DISCUSSION.fields_by_name['owner_community_id'])
_DISCUSSION.fields_by_name['owner_community_id'].containing_oneof = _DISCUSSION.oneofs_by_name['owner']
_DISCUSSION.oneofs_by_name['owner'].fields.append(
  _DISCUSSION.fields_by_name['owner_group_id'])
_DISCUSSION.fields_by_name['owner_group_id'].containing_oneof = _DISCUSSION.oneofs_by_name['owner']
_CREATEDISCUSSIONREQ.oneofs_by_name['owner'].fields.append(
  _CREATEDISCUSSIONREQ.fields_by_name['owner_community_id'])
_CREATEDISCUSSIONREQ.fields_by_name['owner_community_id'].containing_oneof = _CREATEDISCUSSIONREQ.oneofs_by_name['owner']
_CREATEDISCUSSIONREQ.oneofs_by_name['owner'].fields.append(
  _CREATEDISCUSSIONREQ.fields_by_name['owner_group_id'])
_CREATEDISCUSSIONREQ.fields_by_name['owner_group_id'].containing_oneof = _CREATEDISCUSSIONREQ.oneofs_by_name['owner']
DESCRIPTOR.message_types_by_name['Discussion'] = _DISCUSSION
DESCRIPTOR.message_types_by_name['CreateDiscussionReq'] = _CREATEDISCUSSIONREQ
DESCRIPTOR.message_types_by_name['GetDiscussionReq'] = _GETDISCUSSIONREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Discussion = _reflection.GeneratedProtocolMessageType('Discussion', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSION,
  '__module__' : 'discussions_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.discussions.Discussion)
  })
_sym_db.RegisterMessage(Discussion)

CreateDiscussionReq = _reflection.GeneratedProtocolMessageType('CreateDiscussionReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDISCUSSIONREQ,
  '__module__' : 'discussions_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.discussions.CreateDiscussionReq)
  })
_sym_db.RegisterMessage(CreateDiscussionReq)

GetDiscussionReq = _reflection.GeneratedProtocolMessageType('GetDiscussionReq', (_message.Message,), {
  'DESCRIPTOR' : _GETDISCUSSIONREQ,
  '__module__' : 'discussions_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.discussions.GetDiscussionReq)
  })
_sym_db.RegisterMessage(GetDiscussionReq)



_DISCUSSIONS = _descriptor.ServiceDescriptor(
  name='Discussions',
  full_name='org.couchers.api.discussions.Discussions',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=573,
  serialized_end=816,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDiscussion',
    full_name='org.couchers.api.discussions.Discussions.CreateDiscussion',
    index=0,
    containing_service=None,
    input_type=_CREATEDISCUSSIONREQ,
    output_type=_DISCUSSION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDiscussion',
    full_name='org.couchers.api.discussions.Discussions.GetDiscussion',
    index=1,
    containing_service=None,
    input_type=_GETDISCUSSIONREQ,
    output_type=_DISCUSSION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DISCUSSIONS)

DESCRIPTOR.services_by_name['Discussions'] = _DISCUSSIONS

# @@protoc_insertion_point(module_scope)
